@@ -40,3 +40,17 @@ test_that("using a formula", {
 
   expect_equal(mean(out$B), 7164.28)
 })
+
+test_that("using a special formula", {
+
+  set.seed(243556336)
+
+  dag <- empty_dag() +
+    node("A", type="rnorm", mean=12, sd=10) +
+    node("B", type="negative_binomial", formula=~ -2 + A*0.2 + I(A^2)*0.01,
+         theta=0.05)
+
+  out <- sim_from_dag(dag=dag, n_sim=100)
+
+  expect_equal(mean(out$B), 7164.28)
+})
